==> h5p-7.x-1.43.tar.gz: h5p/modules/h5peditor/h5peditor/language/pt.js <==
H5PEditor.language.core = {
  missingTranslation: '[Tradução ausente :key]',
  loading: 'Carregando, aguarde...',
  selectLibrary: 'Selecione a biblioteca que deseja usar em seu conteúdo.',
  unknownFieldPath: 'Incapaz de encontrar ":path".',
  notImageField: '":path" não é uma imagem.',
  notImageOrDimensionsField: '":path" não é uma imagem ou campo de dimensão.',
  requiredProperty: 'O :property é obrigatório e deve ter um valor.',
  onlyNumbers: 'O valor de :property pode conter apenas números.',
  exceedsMax: 'O valor de :property excede o máximo de :max.',
  listExceedsMax: 'A lista excede o número máxima de :max itens.',
  belowMin: 'O valor de :property é menor que o mínimo de :min.',
  listBelowMin: 'A lista precisa de pelo menos :min itens para que o conteúdo funcione corretamente.',
  outOfStep: 'O valor de :property pode ser mudade em escalas de :step.',
  add: 'Adicionar',
  addFile: 'Adicionar arquivo',
  removeFile: 'Remover arquivo',
  confirmRemoval: 'Tem certeza de que deseja remover :type?',
  removeImage: 'Remover imagem',
  confirmImageRemoval: 'Isso removerá sua imagem. Tem certeza de que deseja continuar?',
  changeFile: 'Alterar arquivo',
  changeLibrary: 'Alterar tipo de conteúdo?',
  semanticsError: 'Erro de semântica: :error',
  missingProperty: 'Campo :index não possui sua propriedade :property.',
  expandCollapse: 'Expandir/Recolher',
  addEntity: 'Adicionar :entity',
  tooLong: 'Valor do campo é muito longo, deve conter :max caracteres ou menos.',
  invalidFormat: 'Valor do campo contém um formato inválido ou caracteres proibidos.',
  confirmChangeLibrary: 'Fazendo isso você perderá todo o trabalho concluído com o tipo atual de conteúdo. Tem certeza de que deseja alterar o tipo de conteúdo?',
  commonFields: 'Sobreposição de texto e traduções',
  commonFieldsDescription: 'Aqui você pode editar configurações ou traduzir textos usados neste conteúdo.',
  uploading: 'Enviando, aguarde...',
  noFollow: 'Incapaz de seguir campo ":path".',
  editCopyright: 'Editar direitos autorais',
  close: 'Fechar',
  tutorial: 'Tutorial',
  editMode: 'Modo de edição',
  listLabel: 'Lista',
  uploadError: 'Erro de envio de arquivo',
  fileToLarge: 'O arquivo que você está tentando enviar pode ser muito grande.',
  unknownFileUploadError: 'Erro de envio de arquivo desconhecido',
  noSemantics: 'Erro, não foi possível carregar o formulário do tipo de conteúdo.',
  editImage: 'Editar imagem',
  saveLabel: 'Salvar',
  cancelLabel: 'Cancelar',
  resetToOriginalLabel: 'Resetar para original',
  loadingImageEditor: 'Carregar editor de imagem, aguarde...',
  selectFiletoUpload: 'Selecionar arquivo para enviar',
  or: 'ou',
  enterAudioUrl: 'Insira a URL fonte para o áudio',
  enterVideoUrl: 'Insira a URL fonte para o video ou um link do YouTube',
  enterAudioTitle: 'Cole aqui o link do áudio',
  enterVideoTitle: 'Cole aqui a URL do vídeo ou o link do YouTube',
  uploadAudioTitle: 'Enviar arquivo de áudio',
  uploadVideoTitle: 'Enviar arquivo de vídeo',
  addVideoDescription: 'H5P suporta todos as fontes externas de vídeo com formato mp4, webm ou ogv, como Vimeo Pro, e possui suporte para links do YouTube.',
  insert: 'Inserir',
  cancel: 'Cancelar',
  height: 'altura',
  width: 'largura',
  textField: 'campo de texto',
  numberField: 'campo de número',
  orderItemUp: 'Mover item para cima',
  orderItemDown: 'Mover item para baixo',
  removeItem: 'Remover item',
  hubPanelLabel: 'Selecionar tipo de conteúdo',
  importantInstructions: 'Instruções importantes',
  showImportantInstructions: 'Mostrar instruções',
  hideImportantInstructions: 'Esconder instruções importantes',
  hide: 'Esconder',
  example: 'Exemplo',
  createContentTabLabel: 'Criar conteúdo',
  uploadTabLabel: 'Carregar',
  uploadPlaceholder: 'Nenhum arquivo selecionado',
  uploadInstructionsTitle: 'Carregar um arquivo H5P.',
  uploadInstructionsContent: 'Você pode começar com exemplos em <a href="https://h5p.org/content-types-and-applications" target="blank">H5P.org</a>.',
  uploadFileButtonLabel: 'Carregar um arquivo',
  uploadFileButtonChangeLabel: 'Alterar arquivo',
  uploadingThrobber: 'Carregando...',
  uploadSuccess: ':title foi carregado com sucesso!',
  unableToInterpretError: 'Incapaz de interpretar resposta.',
  unableToInterpretSolution: 'Por favor, verifique seu log de erros.',
  h5pFileWrongExtensionTitle: 'O arquivo selecionado não pôde ser carregado',
  h5pFileWrongExtensionContent: 'Somente arquivos com a extensão .h5p são permitidos.',
  h5pFileValidationFailedTitle: 'Não foi possível validar o arquivo H5P.',
  h5pFileValidationFailedContent: 'Tenha certeza que o H5P carregado possui conteúdo válido H5P. Arquivos H5P que contém apenas bibliotecas devem ser enviados através da página de Bibliotecas H5P.',
  h5pFileUploadServerErrorTitle: 'O arquivo H5P não pôde ser enviado',
  h5pFileUploadServerErrorContent: 'Um erro inesperado ocorreu. Verifique seu o log de erros do servidor para maiores informações.',
  contentTypeSectionAll: 'Todos os tipos de conteúdo',
  searchResults: 'Procurar resultados',
  contentTypeSearchFieldPlaceholder: 'Procurar por tipos de conteúdo',
  contentTypeInstallButtonLabel: 'Instalar',
  contentTypeInstallingButtonLabel: 'Instalando',
  contentTypeUseButtonLabel: 'Usar',
  contentTypeDetailButtonLabel: 'Detalhes',
  contentTypeUpdateButtonLabel: 'Atualizar',
  contentTypeUpdatingButtonLabel: 'Atualizando',
  contentTypeGetButtonLabel: 'Obter',
  contentTypeBackButtonLabel: 'Voltar',
  contentTypeIconAltText: 'ícone',
  contentTypeInstallSuccess: ':contentType instalado com sucesso!',
  contentTypeUpdateSuccess: ':contentType atualizado com sucesso!',
  contentTypeInstallError: ':contentType não pôde ser instalado. Contate seu administrador.',
  contentTypeLicensePanelTitle: 'Licença',
  contentTypeDemoButtonLabel: 'Demonstração de conteúdo',
  numResults: ':num resultados',
  show: 'Mostrar',
  recentlyUsedFirst: 'Recentemente usados primeiro',
  popularFirst: 'Populares primeiro',
  newestFirst: 'Novos primeiro',
  aToZ: 'Ordem alfabética',
  noResultsFound: 'Nenhum resultado encontrado',
  noResultsFoundDesc: 'Não há nenhum tipo de conteúdo que corresponde aos critérios da pesquisa.',
  readMore: 'Veja mais',
  readLess: 'Veja menos',
  contentTypeOwner: 'Por :owner',
  contentTypeUnsupportedApiVersionTitle: 'Este tipo de conteúdo requer uma nova versão principal',
  contentTypeUnsupportedApiVersionContent: 'Contate o administrador de seu sistema para lhe prover as atualizações necessárias',
  contentTypeUpdateAvailable: 'Atualização disponível',
  contentTypeRestricted: 'Tipo de conteúdo restrito',
  contentTypeRestrictedDesc: 'O uso deste tipo de conteúdo foi restringido pelo administrador.',
  contentTypeNotInstalled: 'Tipo de conteúdo não instalado',
  contentTypeNotInstalledDesc: 'Você não possui permissão para instalar tipos de conteúdo.',
  theContentType: 'o tipo de conteúdo',
  currentMenuSelected: 'seleção atual',
  errorCommunicatingHubTitle: 'Incapaz de se comunicar com o hub.',
  errorCommunicatingHubContent: 'Um erro ocorreu. Por favor, tente novamente.',
  warningNoContentTypesInstalled: 'Você não possui nenhum tipo de conteúdo instalado.',
  warningChangeBrowsingToSeeResults: 'Clique em <em>todos</em> para obter uma lista de todos os conteúdos que você pode instalar.',
  warningUpdateAvailableTitle: 'Uma nova versão de :contentType está disponível.',
  warningUpdateAvailableBody: 'Atualize para a última versão para uma experiência melhorada.',
  licenseDescription: 'Algumas das características desta licença são indicadas abaixo. Clique o ícone de informações acima para ler o texto original da licença. ',
  licenseModalTitle: 'Detalhes da licença',
  licenseModalSubtitle: 'Selecione uma licença para ver informações sobre seu uso apropriado',
  licenseUnspecified: 'Não informado',
  licenseCanUseCommercially: 'Pode usar comercialmente',
  licenseCanModify: 'Pode modificar',
  licenseCanDistribute: 'Pode distribuir',
  licenseCanSublicense: 'Pode sub-licenciar',
  licenseCanHoldLiable: 'Pode ser responsabilizado',
  licenseCannotHoldLiable: 'Não pode ser responsabilizado',
  licenseMustIncludeCopyright: 'Precisa incluir direitos autorais',
  licenseMustIncludeLicense: 'Precisa incluir licença',
  licenseFetchDetailsFailed: 'Falha em buscar detalhes da licença',
  imageLightboxTitle: 'Imagens',
  imageLightBoxProgress: ':num de :total',
  nextImage: 'Próxima imagem',
  previousImage: 'Imagem anterior',
  screenshots: 'Capturas de tela',
  reloadButtonLabel: 'Recarregar',
  videoQuality: 'Rótulo de qualidade de vídeo',
  videoQualityDescription: 'Este rótulo ajuda o usuário a identificar a qualidade atual do vídeo. Ex.: 1080p, 720p, HD ou Mobile',
  videoQualityDefaultLabel: 'Qualidade :index',
  noContentTypesAvailable: 'Nenhum tipo de conteúdo está disponível',
  noContentTypesAvailableDesc: 'Seu site está tendo dificuldades ao conectar ao H5P.org e listar os tipos de conteúdo disponíveis.',
  contentTypeCacheOutdated: 'Lista de tipos de conteúdo desatualizada',
  contentTypeCacheOutdatedDesc: 'Seu site está tendo dificuldades ao conectar ao H5P.org e verificar os tipos de conteúdo disponíveis. Você pode não ser capaz de atualizar ou instalar novos tipos de conteúdo.',
  tryAgain: 'Tentar novamente',
  getHelp: 'Obter ajuda',
  untitled: 'Sem título :libraryTitle',
  title: 'Título',
  metadata: 'Metadados',
  addTitle: 'Adicionar título',
  usedForSearchingReportsAndCopyrightInformation: 'Usado para pesquisas, relatórios e informações de direitos autorais',
  metadataSharingAndLicensingInfo: 'Metadados (informações de compartilhamento e licenciamento)',
  fillInTheFieldsBelow: 'Preencha os campos abaixo',
  saveMetadata: 'Salvar metadados',
  addAuthor: 'Save author',
  confirmRemoveAuthor: 'Are you sure you would like to remove this author?',
  addNewChange: 'Adicionar nova alteração',
  confirmDeleteChangeLog: 'Are you sure you would like to delete this change log entry?',
  changelogDescription: 'Some licenses require that changes made to the original work, or derivatives are logged and displayed. You may log your changes here for licensing reasons or just to allow yourself and others to keep track of the changes made to this content.',
  logThisChange: 'Registrar alteração',
  newChangeHasBeenLogged: 'A nova alteração foi registrada no log',
  loggedChanges: 'Alterações registradas',
  noChangesHaveBeenLogged: 'Nenhuma alteração foi registrada',
  errorHeader: 'Um erro ocorreu',
  errorCalculatingMaxScore: 'Não foi possível calcular a pontuação máxima para este conteúdo. A pontuação máxima é assumida como sendo 0. Contate seu administrador se isto não estiver correto.',
  maxScoreSemanticsMissing: 'Não foi possível encontrar a semântica esperada no conteúdo.',
  copyButton: 'Copiar',
  copiedButton: 'Copiado',
  pasteButton: 'Colar',
  pasteAndReplaceButton: 'Paste & Replace',
  pasteContent: 'Replace Content',
  confirmPasteContent: 'By doing this you will replace the current content with the content from your clipboard. The current content will be lost. Are you sure you wish to continue?',
  confirmPasteButtonText: 'Replace content',
  copyToClipboard: 'Copiar conteúdo H5P para o painel',
  copiedToClipboard: 'O conteúdo foi copiado para o painel',
  pasteFromClipboard: 'Colar conteúdo H5P do painel',
  pasteAndReplaceFromClipboard: 'Replace existing content with H5P Content from the clipboard',
  pasteNoContent: 'Não há conteúdo H5P no painel',
  pasteError: 'Não foi possível colar',
  pasteContentNotSupported: 'O conteúdo que você está tentando colar não é suportado neste contexto',
  pasteTooOld: 'O conteúdo que você está tentando colar é de uma versão inferior (:clip) à versão suportada neste contexto (:local), se possível, tente atualizar o conteúdo que deseja colar, copie-o novamente e tente colá-lo aqui.',
  pasteTooNew: 'O conteúdo que você está tentando colar é de uma versão superior (:clip) à versão suportada neste contexto (:local), se possível, tente atualizar este conteúdo, e então tente colar novamente.',
  ok: 'OK',
  avTablistLabel: 'Insert using',
  tabTitleBasicFileUpload: 'File Upload',
  tabTitleInputLinkURL: 'Link/URL',
  errorTooHighVersion: 'Parameters contain %used while only %supported or earlier are supported.',
  errorNotSupported: 'Parameters contain %used which is not supported.',
  errorParamsBroken: 'Parameters are broken.',
  libraryMissing: 'Missing required library %lib.',
  scriptMissing: 'Could not load upgrades script for %lib.',
  language: 'Language',
  noLanguagesSupported: 'No languages supported',
  changeLanguage: 'Change language to :language?',
  thisWillPotentially: "This will potentially reset all the text and translations. You can't undo this. The content itself will not be changed. Do you want to proceed?",
  notAllTextsChanged: 'Not all texts were changed, there is only partial coverage for :language.',
  contributeTranslations: 'If you want to complete the translation for :language you can learn about <a href=":url" target="_new">contributing translations to H5P</a>'
};

==> h5p-7.x-1.44.tar.gz: h5p/modules/h5peditor/h5peditor/language/pt.js <==
H5PEditor.language.core = {
  missingTranslation: '[Tradução ausente :key]',
  loading: 'Carregando, aguarde...',
  selectLibrary: 'Selecione a biblioteca que deseja usar em seu conteúdo.',
  unknownFieldPath: 'Incapaz de encontrar ":path".',
  notImageField: '":path" não é uma imagem.',
  notImageOrDimensionsField: '":path" não é uma imagem ou campo de dimensão.',
  requiredProperty: 'O :property é obrigatório e deve ter um valor.',
  onlyNumbers: 'O valor de :property pode conter apenas números.',
  illegalDecimalNumber: ':property can only contain numbers with max :decimals decimals.',
  exceedsMax: 'O valor de :property excede o máximo de :max.',
  listExceedsMax: 'A lista excede o número máxima de :max itens.',
  belowMin: 'O valor de :property é menor que o mínimo de :min.',
  listBelowMin: 'A lista precisa de pelo menos :min itens para que o conteúdo funcione corretamente.',
  outOfStep: 'O valor de :property pode ser mudade em escalas de :step.',
  add: 'Adicionar',
  addFile: 'Adicionar arquivo',
  removeFile: 'Remover arquivo',
  confirmRemoval: 'Tem certeza de que deseja remover :type?',
  removeImage: 'Remover imagem',
  confirmImageRemoval: 'Isso removerá sua imagem. Tem certeza de que deseja continuar?',
  changeFile: 'Alterar arquivo',
  changeLibrary: 'Alterar tipo de conteúdo?',
  semanticsError: 'Erro de semântica: :error',
  missingProperty: 'Campo :index não possui sua propriedade :property.',
  expandCollapse: 'Expandir/Recolher',
  addEntity: 'Adicionar :entity',
  tooLong: 'Valor do campo é muito longo, deve conter :max caracteres ou menos.',
  invalidFormat: 'Valor do campo contém um formato inválido ou caracteres proibidos.',
  confirmChangeLibrary: 'Fazendo isso você perderá todo o trabalho concluído com o tipo atual de conteúdo. Tem certeza de que deseja alterar o tipo de conteúdo?',
  commonFields: 'Sobreposição de texto e traduções',
  commonFieldsDescription: 'Aqui você pode editar configurações ou traduzir textos usados neste conteúdo.',
  uploading: 'Enviando, aguarde...',
  noFollow: 'Incapaz de seguir campo ":path".',
  editCopyright: 'Editar direitos autorais',
  close: 'Fechar',
  tutorial: 'Tutorial',
  editMode: 'Modo de edição',
  listLabel: 'Lista',
  uploadError: 'Erro de envio de arquivo',
  fileToLarge: 'O arquivo que você está tentando enviar pode ser muito grande.',
  unknownFileUploadError: 'Erro de envio de arquivo desconhecido',
  noSemantics: 'Erro, não foi possível carregar o formulário do tipo de conteúdo.',
  editImage: 'Editar imagem',
  saveLabel: 'Salvar',
  cancelLabel: 'Cancelar',
  resetToOriginalLabel: 'Resetar para original',
  loadingImageEditor: 'Carregar editor de imagem, aguarde...',
  selectFiletoUpload: 'Selecionar arquivo para enviar',
  or: 'ou',
  enterAudioUrl: 'Insira a URL fonte para o áudio',
  enterVideoUrl: 'Insira a URL fonte para o video ou um link do YouTube',
  enterAudioTitle: 'Cole aqui o link do áudio',
  enterVideoTitle: 'Cole aqui a URL do vídeo ou o link do YouTube',
  uploadAudioTitle: 'Enviar arquivo de áudio',
  uploadVideoTitle: 'Enviar arquivo de vídeo',
  addVideoDescription: 'H5P suporta todos as fontes externas de vídeo com formato mp4, webm ou ogv, como Vimeo Pro, e possui suporte para links do YouTube.',
  insert: 'Inserir',
  cancel: 'Cancelar',
  height: 'altura',
  width: 'largura',
  textField: 'campo de texto',
  numberField: 'campo de número',
  orderItemUp: 'Mover item para cima',
  orderItemDown: 'Mover item para baixo',
  removeItem: 'Remover item',
  hubPanelLabel: 'Selecionar tipo de conteúdo',
  importantInstructions: 'Instruções importantes',
  showImportantInstructions: 'Mostrar instruções',
  hideImportantInstructions: 'Esconder instruções importantes',
  hide: 'Esconder',
  example: 'Exemplo',
  createContentTabLabel: 'Criar conteúdo',
  uploadTabLabel: 'Carregar',
  uploadPlaceholder: 'Nenhum arquivo selecionado',
  uploadInstructionsTitle: 'Carregar um arquivo H5P.',
  uploadInstructionsContent: 'Você pode começar com exemplos em <a href="https://h5p.org/content-types-and-applications" target="blank">H5P.org</a>.',
  uploadFileButtonLabel: 'Carregar um arquivo',
  uploadFileButtonChangeLabel: 'Alterar arquivo',
  uploadingThrobber: 'Carregando...',
  uploadSuccess: ':title foi carregado com sucesso!',
  unableToInterpretError: 'Incapaz de interpretar resposta.',
  unableToInterpretSolution: 'Por favor, verifique seu log de erros.',
  h5pFileWrongExtensionTitle: 'O arquivo selecionado não pôde ser carregado',
  h5pFileWrongExtensionContent: 'Somente arquivos com a extensão .h5p são permitidos.',
  h5pFileValidationFailedTitle: 'Não foi possível validar o arquivo H5P.',
  h5pFileValidationFailedContent: 'Tenha certeza que o H5P carregado possui conteúdo válido H5P. Arquivos H5P que contém apenas bibliotecas devem ser enviados através da página de Bibliotecas H5P.',
  h5pFileUploadServerErrorTitle: 'O arquivo H5P não pôde ser enviado',
  h5pFileUploadServerErrorContent: 'Um erro inesperado ocorreu. Verifique seu o log de erros do servidor para maiores informações.',
  contentTypeSectionAll: 'Todos os tipos de conteúdo',
  searchResults: 'Procurar resultados',
  contentTypeSearchFieldPlaceholder: 'Procurar por tipos de conteúdo',
  contentTypeInstallButtonLabel: 'Instalar',
  contentTypeInstallingButtonLabel: 'Instalando',
  contentTypeUseButtonLabel: 'Usar',
  contentTypeDetailButtonLabel: 'Detalhes',
  contentTypeUpdateButtonLabel: 'Atualizar',
  contentTypeUpdatingButtonLabel: 'Atualizando',
  contentTypeGetButtonLabel: 'Obter',
  contentTypeBackButtonLabel: 'Voltar',
  contentTypeIconAltText: 'ícone',
  contentTypeInstallSuccess: ':contentType instalado com sucesso!',
  contentTypeUpdateSuccess: ':contentType atualizado com sucesso!',
  contentTypeInstallError: ':contentType não pôde ser instalado. Contate seu administrador.',
  contentTypeLicensePanelTitle: 'Licença',
  contentTypeDemoButtonLabel: 'Demonstração de conteúdo',
  numResults: ':num resultados',
  show: 'Mostrar',
  recentlyUsedFirst: 'Recentemente usados primeiro',
  popularFirst: 'Populares primeiro',
  newestFirst: 'Novos primeiro',
  aToZ: 'Ordem alfabética',
  noResultsFound: 'Nenhum resultado encontrado',
  noResultsFoundDesc: 'Não há nenhum tipo de conteúdo que corresponde aos critérios da pesquisa.',
  readMore: 'Veja mais',
  readLess: 'Veja menos',
  contentTypeOwner: 'Por :owner',
  contentTypeUnsupportedApiVersionTitle: 'Este tipo de conteúdo requer uma nova versão principal',
  contentTypeUnsupportedApiVersionContent: 'Contate o administrador de seu sistema para lhe prover as atualizações necessárias',
  contentTypeUpdateAvailable: 'Atualização disponível',
  contentTypeRestricted: 'Tipo de conteúdo restrito',
  contentTypeRestrictedDesc: 'O uso deste tipo de conteúdo foi restringido pelo administrador.',
  contentTypeNotInstalled: 'Tipo de conteúdo não instalado',
  contentTypeNotInstalledDesc: 'Você não possui permissão para instalar tipos de conteúdo.',
  theContentType: 'o tipo de conteúdo',
  currentMenuSelected: 'seleção atual',
  errorCommunicatingHubTitle: 'Incapaz de se comunicar com o hub.',
  errorCommunicatingHubContent: 'Um erro ocorreu. Por favor, tente novamente.',
  warningNoContentTypesInstalled: 'Você não possui nenhum tipo de conteúdo instalado.',
  warningChangeBrowsingToSeeResults: 'Clique em <em>todos</em> para obter uma lista de todos os conteúdos que você pode instalar.',
  warningUpdateAvailableTitle: 'Uma nova versão de :contentType está disponível.',
  warningUpdateAvailableBody: 'Atualize para a última versão para uma experiência melhorada.',
  licenseDescription: 'Algumas das características desta licença são indicadas abaixo. Clique o ícone de informações acima para ler o texto original da licença. ',
  licenseModalTitle: 'Detalhes da licença',
  licenseModalSubtitle: 'Selecione uma licença para ver informações sobre seu uso apropriado',
  licenseUnspecified: 'Não informado',
  licenseCanUseCommercially: 'Pode usar comercialmente',
  licenseCanModify: 'Pode modificar',
  licenseCanDistribute: 'Pode distribuir',
  licenseCanSublicense: 'Pode sub-licenciar',
  licenseCanHoldLiable: 'Pode ser responsabilizado',
  licenseCannotHoldLiable: 'Não pode ser responsabilizado',
  licenseMustIncludeCopyright: 'Precisa incluir direitos autorais',
  licenseMustIncludeLicense: 'Precisa incluir licença',
  licenseFetchDetailsFailed: 'Falha em buscar detalhes da licença',
  imageLightboxTitle: 'Imagens',
  imageLightBoxProgress: ':num de :total',
  nextImage: 'Próxima imagem',
  previousImage: 'Imagem anterior',
  screenshots: 'Capturas de tela',
  reloadButtonLabel: 'Recarregar',
  videoQuality: 'Rótulo de qualidade de vídeo',
  videoQualityDescription: 'Este rótulo ajuda o usuário a identificar a qualidade atual do vídeo. Ex.: 1080p, 720p, HD ou Mobile',
  videoQualityDefaultLabel: 'Qualidade :index',
  noContentTypesAvailable: 'Nenhum tipo de conteúdo está disponível',
  noContentTypesAvailableDesc: 'Seu site está tendo dificuldades ao conectar ao H5P.org e listar os tipos de conteúdo disponíveis.',
  contentTypeCacheOutdated: 'Lista de tipos de conteúdo desatualizada',
  contentTypeCacheOutdatedDesc: 'Seu site está tendo dificuldades ao conectar ao H5P.org e verificar os tipos de conteúdo disponíveis. Você pode não ser capaz de atualizar ou instalar novos tipos de conteúdo.',
  tryAgain: 'Tentar novamente',
  getHelp: 'Obter ajuda',
  untitled: 'Sem título :libraryTitle',
  title: 'Título',
  metadata: 'Metadados',
  addTitle: 'Adicionar título',
  usedForSearchingReportsAndCopyrightInformation: 'Usado para pesquisas, relatórios e informações de direitos autorais',
  metadataSharingAndLicensingInfo: 'Metadados (informações de compartilhamento e licenciamento)',
  fillInTheFieldsBelow: 'Preencha os campos abaixo',
  saveMetadata: 'Salvar metadados',
  addAuthor: 'Save author',
  confirmRemoveAuthor: 'Are you sure you would like to remove this author?',
  addNewChange: 'Adicionar nova alteração',
  confirmDeleteChangeLog: 'Are you sure you would like to delete this change log entry?',
  changelogDescription: 'Some licenses require that changes made to the original work, or derivatives are logged and displayed. You may log your changes here for licensing reasons or just to allow yourself and others to keep track of the changes made to this content.',
  logThisChange: 'Registrar alteração',
  newChangeHasBeenLogged: 'A nova alteração foi registrada no log',
  loggedChanges: 'Alterações registradas',
  noChangesHaveBeenLogged: 'Nenhuma alteração foi registrada',
  errorHeader: 'Um erro ocorreu',
  errorCalculatingMaxScore: 'Não foi possível calcular a pontuação máxima para este conteúdo. A pontuação máxima é assumida como sendo 0. Contate seu administrador se isto não estiver correto.',
  maxScoreSemanticsMissing: 'Não foi possível encontrar a semântica esperada no conteúdo.',
  copyButton: 'Copiar',
  copiedButton: 'Copiado',
  pasteButton: 'Colar',
  pasteAndReplaceButton: 'Paste & Replace',
  pasteContent: 'Replace Content',
  confirmPasteContent: 'By doing this you will replace the current content with the content from your clipboard. The current content will be lost. Are you sure you wish to continue?',
  confirmPasteButtonText: 'Replace content',
  copyToClipboard: 'Copiar conteúdo H5P para o painel',
  copiedToClipboard: 'O conteúdo foi copiado para o painel',
  pasteFromClipboard: 'Colar conteúdo H5P do painel',
  pasteAndReplaceFromClipboard: 'Replace existing content with H5P Content from the clipboard',
  pasteNoContent: 'Não há conteúdo H5P no painel',
  pasteError: 'Não foi possível colar',
  pasteContentNotSupported: 'O conteúdo que você está tentando colar não é suportado neste contexto',
  pasteTooOld: 'O conteúdo que você está tentando colar é de uma versão inferior (:clip) à versão suportada neste contexto (:local), se possível, tente atualizar o conteúdo que deseja colar, copie-o novamente e tente colá-lo aqui.',
  pasteTooNew: 'O conteúdo que você está tentando colar é de uma versão superior (:clip) à versão suportada neste contexto (:local), se possível, tente atualizar este conteúdo, e então tente colar novamente.',
  ok: 'OK',
  avTablistLabel: 'Insert using',
  tabTitleBasicFileUpload: 'File Upload',
  tabTitleInputLinkURL: 'Link/URL',
  errorTooHighVersion: 'Parameters contain %used while only %supported or earlier are supported.',
  errorNotSupported: 'Parameters contain %used which is not supported.',
  errorParamsBroken: 'Parameters are broken.',
  libraryMissing: 'Missing required library %lib.',
  scriptMissing: 'Could not load upgrades script for %lib.',
  language: 'Language',
  noLanguagesSupported: 'No languages supported',
  changeLanguage: 'Change language to :language?',
  thisWillPotentially: "This will potentially reset all the text and translations. You can't undo this. The content itself will not be changed. Do you want to proceed?",
  notAllTextsChanged: 'Not all texts were changed, there is only partial coverage for :language.',
  contributeTranslations: 'If you want to complete the translation for :language you can learn about <a href=":url" target="_new">contributing translations to H5P</a>',
  unknownLibrary: 'Unfortunately, the selected content type \'%lib\' isn\'t installed on this system.',
  proceedButtonLabel: 'Proceed to save',
  enterFullscreenButtonLabel: 'Enter fullscreen',
  exitFullscreenButtonLabel: 'Exit fullscreen'
};
